@@ -9,6 +9,7 @@ from libcst import (
     ClassDef,
     FunctionDef,
     ImportFrom,
+    ImportStar,
     Module,
     Name,
     Param,
@@ -32,6 +33,8 @@ class InlineHasAddPermissionsTransformer(BaseDjCodemodTransformer):
     def leave_ImportFrom(
         self, original_node: ImportFrom, updated_node: ImportFrom
     ) -> Union[BaseSmallStatement, RemovalSentinel]:
+        if isinstance(updated_node.names, ImportStar):
+            return super().leave_ImportFrom(original_node, updated_node)
         base_cls_matcher = []
         if m.matches(
             updated_node,
