@@ -1,7 +1,8 @@
-from typing import Optional, Union
+from typing import Generator, Optional, Sequence, Union
 
 from libcst import (
     Assign,
+    AssignTarget,
     Decorator,
     ImportFrom,
     ImportStar,
@@ -41,49 +42,53 @@ class AssignmentTagTransformer(BaseDjCodemodTransformer):
 
     def visit_ImportFrom(self, node: ImportFrom) -> Optional[bool]:
         """Record whether an interesting import is detected."""
-        return self._check_template_imported(node) or self._check_library_imported(node)
+        import_matcher = (
+            # django.template
+            self._template_import_matcher(node)
+            # django.template.Library
+            or self._library_import_matcher(node)
+        )
+        if import_matcher:
+            self.context.scratch[self.ctx_key_library_call_matcher] = import_matcher
+        return None
 
-    def _check_template_imported(self, node: ImportFrom) -> bool:
-        """Record matcher if django.template is imported."""
-        if not import_from_matches(node, ["django"]) or isinstance(
-            node.names, ImportStar
-        ):
-            return False
+    def _template_import_matcher(self, node: ImportFrom) -> Optional[m.Call]:
+        """Return matcher if django.template is imported."""
+        imported_name_str = self._get_imported_name(node, "django.template")
+        if not imported_name_str:
+            return None
+        # Build the `Call` matcher to look out for, e.g. `template.Library()`
+        return m.Call(
+            func=m.Attribute(
+                attr=m.Name("Library"), value=m.Name(value=imported_name_str)
+            )
+        )
+
+    def _library_import_matcher(self, node: ImportFrom) -> Optional[m.Call]:
+        """Return matcher if django.template.Library is imported."""
+        imported_name_str = self._get_imported_name(node, "django.template.Library")
+        if not imported_name_str:
+            return None
+        # Build the `Call` matcher to look out for, e.g. `Library()`
+        return m.Call(func=m.Name(imported_name_str))
+
+    @staticmethod
+    def _get_imported_name(node: ImportFrom, import_path: str) -> Optional[str]:
+        """Resolve the imported name if present."""
+        if isinstance(node.names, ImportStar):
+            return None
+        *modules, name = import_path.split(".")
+        if not import_from_matches(node, modules):
+            return None
         for import_alias in node.names:
-            if m.matches(import_alias, m.ImportAlias(name=m.Name("template"))):
-                # We're visiting the `from django import template` statement
+            if m.matches(import_alias, m.ImportAlias(name=m.Name(name))):
+                # We're visiting the import statement we're looking for
                 # Get the actual name it's imported as (in case of import alias)
                 imported_name_str = (
                     import_alias.evaluated_alias or import_alias.evaluated_name
                 )
-                # Build the `Call` matcher to look out for, eg `template.Library()`
-                self.context.scratch[self.ctx_key_library_call_matcher] = m.Call(
-                    func=m.Attribute(
-                        attr=m.Name("Library"), value=m.Name(value=imported_name_str)
-                    )
-                )
-                return True
-        return False
-
-    def _check_library_imported(self, node: ImportFrom) -> bool:
-        """Record matcher if django.template.Library is imported."""
-        if not import_from_matches(node, ["django", "template"]) or isinstance(
-            node.names, ImportStar
-        ):
-            return False
-        for import_alias in node.names:
-            if m.matches(import_alias, m.ImportAlias(name=m.Name("Library"))):
-                # We're visiting the `from django.template import Library` statement
-                # Get the actual name it's imported as (in case of import alias)
-                imported_name_str = (
-                    import_alias.evaluated_alias or import_alias.evaluated_name
-                )
-                # Build the `Call` matcher to look out for, eg `Library()`
-                self.context.scratch[self.ctx_key_library_call_matcher] = m.Call(
-                    func=m.Name(imported_name_str)
-                )
-                return True
-        return False
+                return imported_name_str
+        return None
 
     def visit_Assign(self, node: Assign) -> Optional[bool]:
         """Record variable name the `Library()` call is assigned to."""
@@ -92,26 +97,31 @@ class AssignmentTagTransformer(BaseDjCodemodTransformer):
             m.Assign(value=self.library_call_matcher),
         ):
             # Visiting a `register = template.Library()` statement
-            # Get all names on the left side of the assignment
-            target_names = (
-                assign_target.target.value  # type: ignore
-                for assign_target in node.targets
+            # Generate decorator matchers based on left hand side names
+            decorator_matchers = self._gen_decorator_matchers(node.targets)
+            # should match if any of the decorator matches
+            self.context.scratch[self.ctx_key_decorator_matcher] = m.OneOf(
+                *decorator_matchers
             )
-            # Build the decorator matchers to look out for
-            target_matchers = (
-                m.Decorator(
+        return super().visit_Assign(node)
+
+    @staticmethod
+    def _gen_decorator_matchers(
+        assign_targets: Sequence[AssignTarget],
+    ) -> Generator[m.Decorator, None, None]:
+        """Generate matchers for all possible decorators."""
+        for assign_target in assign_targets:
+            # for each variable it's assigned to
+            if isinstance(assign_target.target, Name):
+                # get the name of the target
+                target_str = assign_target.target.value
+                # matcher we should use for finding decorators to modify
+                yield m.Decorator(
                     decorator=m.Attribute(
-                        value=m.Name(name),
+                        value=m.Name(target_str),
                         attr=m.Name("assignment_tag"),
                     )
                 )
-                for name in target_names
-            )
-            # The final matcher should match if any of the decorator matchers matches
-            self.context.scratch[self.ctx_key_decorator_matcher] = m.OneOf(
-                *target_matchers
-            )
-        return super().visit_Assign(node)
 
     def leave_Decorator(
         self, original_node: Decorator, updated_node: Decorator
@@ -119,7 +129,7 @@ class AssignmentTagTransformer(BaseDjCodemodTransformer):
         """Update decorator call if all conditions are met."""
         if self.decorators_matcher and m.matches(updated_node, self.decorators_matcher):
             # If we have a decorator matcher, and it matches,
-            # update the node with new name
+            # then update the node with new name
             updated_decorator = updated_node.decorator.with_changes(
                 attr=Name("simple_tag")
             )
